@@ -1,6 +1,6 @@
 ;;; ediff-tbar.el --- A toolbar for Ediff control buffer
 
-;; Copyright (C) 1996, 1997 Free Software Foundation, Inc.
+;; Copyright (C) 1996, 97, 2002 Free Software Foundation, Inc.
 
 ;; Author: Marc Paquette <marcpa@cam.org>
 
@@ -33,6 +33,7 @@
     (or (featurep 'ediff-util)
 	(load "ediff-util.el" nil nil 'nosuffix))
     ))
+(defvar toolbar-icon-directory)
 ;; end pacifier
 
 (require 'ediff-init)
@@ -286,9 +287,6 @@ Here's an example:
       '([ediff-toolbar-refine-icon
 	 ediff-toolbar-refine
 	 t
-	 ;;; The toolbar is not automatically refreshed (in 19.14)
-	 ;;; when :activep changes state. 
-	 ;;(ediff-toolbar-refine-needed-p)
 	 "Refine current difference region by computing fine diffs."]
 	[ediff-toolbar-previous-icon
 	 ediff-toolbar-previous-difference
@@ -334,9 +332,6 @@ Here's an example:
       '([ediff-toolbar-refine-icon
 	 ediff-toolbar-refine
 	 t
-	 ;;; The toolbar is not automatically refreshed (in 19.14)
-	 ;;; when :activep changes state. 
-	 ;;(ediff-toolbar-refine-needed-p)
 	 "Refine current difference region by computing fine diffs."]
 	[ediff-toolbar-previous-icon
 	 ediff-toolbar-previous-difference
